@@ -32,6 +32,7 @@ from making_with_code_cli.cli_setup import (
     choose_course,
     choose_editor,
     MWCShellConfig,
+    InstallCurl,
     InstallHomebrew,
     InstallXCode,
     WriteShellConfig,
@@ -106,6 +107,7 @@ def setup(ctx, yes, teacher, config, debug):
 
     tasks = [
         MWCShellConfig(settings),
+        InstallCurl(settings),
         InstallHomebrew(settings),
         InstallXCode(settings),
         InstallPoetry(settings),
