@@ -320,6 +320,9 @@ class InstallPackage(SetupTask):
         else:
             raise IOError(f"Platform {platform} not supported...")
 
+class InstallCurl(InstallPackage):
+    package_name = brew_name = apt_name = "curl"
+
 class InstallPython3(InstallPackage):
     package_name = brew_name = apt_name = "python3"
 
