@@ -20,6 +20,11 @@ class GitBackend:
         'mkdir'
     ]
 
+    @classmethod
+    def extend_settings(self, settings):
+        "A hook for git backends to collect additional information from the user"
+        return settings
+
     def __init__(self, settings):
         self.settings = settings
 
